#[non_exhaustive]pub enum ModelFault {
Pass,
FailOpen(ModelError),
DisconnectAfterEvents(usize),
DisconnectAfterToolCall,
}Expand description
Fault applied to one model invocation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pass
Executes the invocation without injection.
FailOpen(ModelError)
Fails before a canonical stream is opened.
DisconnectAfterEvents(usize)
Ends the stream after the specified number of canonical events.
DisconnectAfterToolCall
Ends the stream immediately after the first completed Tool call.