FaultController

Struct FaultController 

pub struct FaultController { /* private fields */ }
Shared deterministic fault plan and execution counters.

Implementations

Source

impl FaultController

pub fn new() -> Self

Creates an empty fault plan.

pub fn model_fault(self, fault: ModelFault) -> Self

Queues a fault for the next model invocation.

pub fn disconnect_after_tool_call(self) -> Self

Disconnects the next model stream after a completed Tool call.

pub fn disconnect_after_model_events(self, events: usize) -> Self

Disconnects the next model stream after events canonical events.

pub fn fail_next_model(self, error: ModelError) -> Self

Fails the next model invocation before opening its stream.

pub fn tool_fault(self, fault: ToolFault) -> Self

Queues a named Tool fault.

pub fn fail_tool_on_invocation( self, tool: impl Into<String>, invocation: u64, error: ToolError, ) -> Self

Fails the selected one-based invocation of a named Tool.

pub fn model<M>(&self, model: M) -> FaultInjectingModel<M>
where M: Model,

Wraps a model with this plan.

pub fn tool(&self, tool: Arc<dyn Tool>) -> FaultInjectingTool

Wraps a Tool with this plan.

pub fn tool_invocations(&self, tool: &str) -> u64

Returns the number of observed invocations for one Tool.

pub fn tool_executions(&self, tool: &str) -> u64

Returns the number of calls forwarded to the underlying Tool.

pub fn runtime_restarts(&self) -> u64

Returns the number of explicit runtime reconstructions.

pub fn assert_tool_executed_exactly( &self, tool: &str, expected: u64, ) -> Result<(), ScenarioAssertionError>

Asserts exact Tool execution count with a typed failure.

Errors

Returns ScenarioAssertionError when the observed count differs.