EvaluationError

Enum EvaluationError 

#[non_exhaustive]
pub enum EvaluationError { EmptyField { field: &'static str, }, EmptyDataset, EmptyRules, InconsistentReport { message: &'static str, }, NoScorers, DuplicateCase { case_id: String, }, DuplicateScorer { scorer: String, }, InvalidRatio { field: &'static str, value: f64, }, InvalidMetric { field: &'static str, value: f64, }, Target { message: String, }, Scorer { scorer: String, message: String, }, DatasetMismatch { baseline_name: String, baseline_version: String, candidate_name: String, candidate_version: String, }, }
Evaluation configuration or execution failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyField

A required name or version was empty.

Fields

field: &'static str

Invalid field name.



EmptyDataset

A dataset contains no cases.



EmptyRules

A rule scorer contains no rules.



InconsistentReport

A serialized report contradicts its per-case evidence.

Fields

message: &'static str

Stable inconsistency explanation.



NoScorers

A runner without scorers cannot measure quality.



DuplicateCase

A case identifier occurs more than once.

Fields

case_id: String

Duplicated case identifier.



DuplicateScorer

A scorer name occurs more than once.

Fields

scorer: String

Duplicated scorer name.



InvalidRatio

A score or threshold is not finite and within zero through one.

Fields

field: &'static str

Invalid field name.

value: f64

Rejected value.



InvalidMetric

A duration or monetary metric was negative or non-finite.

Fields

field: &'static str

Invalid field name.

value: f64

Rejected value.



Target

The evaluated target failed to produce an output.

Fields

message: String

Safe failure explanation.



Scorer

A scorer could not evaluate one output.

Fields

scorer: String

Stable scorer name.

message: String

Safe failure explanation.



DatasetMismatch

Reports from different dataset identities cannot be compared.

Fields

baseline_name: String

Baseline dataset name.

baseline_version: String

Baseline dataset version.

candidate_name: String

Candidate dataset name.

candidate_version: String

Candidate dataset version.